DragAndDropView class

Inheritance
Available extensions

Constructors

DragAndDropView({Key? key, bool reverse = false, Widget? header, ScrollController? controller, bool? primary, ScrollPhysics? physics, bool isCustomFeedback = false, bool isCustomChildWhenDragging = false, required WillAcceptCallback onWillAccept, required ReorderCallback onReorder, EdgeInsetsGeometry? padding, required SliverGridDelegate gridDelegate, required IndexedWidgetBuilder itemBuilder, int? itemCount, bool addAutomaticKeepAlives = true, bool addRepaintBoundaries = true, bool addSemanticIndexes = true, double? cacheExtent, int? semanticChildCount, DragStartBehavior dragStartBehavior = DragStartBehavior.start, ScrollViewKeyboardDismissBehavior keyboardDismissBehavior = ScrollViewKeyboardDismissBehavior.manual, WidgetPositionBuilder? feedback, WidgetPositionBuilder? childWhenDragging})
DragAndDropGridView has the all same parameters (except shrinkWrap and scrollDirection) that GridView.builder constructor
const
DragAndDropView.horizontal({Key? key, bool reverse = false, ScrollController? controller, bool? primary, ScrollPhysics? physics, bool isCustomFeedback = false, bool isCustomChildWhenDragging = false, required WillAcceptCallback onWillAccept, required ReorderCallback onReorder, EdgeInsetsGeometry? padding, required SliverGridDelegate gridDelegate, required IndexedWidgetBuilder itemBuilder, int? itemCount, bool addAutomaticKeepAlives = true, bool addRepaintBoundaries = true, bool addSemanticIndexes = true, double? cacheExtent, int? semanticChildCount, DragStartBehavior dragStartBehavior = DragStartBehavior.start, ScrollViewKeyboardDismissBehavior keyboardDismissBehavior = ScrollViewKeyboardDismissBehavior.manual, WidgetPositionBuilder? feedback, WidgetPositionBuilder? childWhenDragging})
This constructor use to achive the Horizontal Reorderable / Re-Indexing feature in DragAndDropGridView. Providing a non-null itemCount improves the ability of the GridView to estimate the maximum scroll extent.
const
DragAndDropView.horizontalStickyHeader({Key? key, bool reverse = false, ScrollController? controller, bool? primary, ScrollPhysics? physics, bool isCustomFeedback = false, bool isCustomChildWhenDragging = false, required WillAcceptCallback onWillAccept, WillAcceptCallback? onWillAcceptHeader, required IndexedWidgetBuilder itemBuilderHeader, bool allHeaderChildNonDraggable = false, SliverGridDelegate? headerGridDelegate, required ReorderCallback onReorder, ReorderCallback? onReorderHeader, int? headerItemCount, EdgeInsetsGeometry? headerPadding, EdgeInsetsGeometry? padding, required SliverGridDelegate gridDelegate, required IndexedWidgetBuilder itemBuilder, int? itemCount, bool addAutomaticKeepAlives = true, bool addRepaintBoundaries = true, bool addSemanticIndexes = true, double? cacheExtent, int? semanticChildCount, DragStartBehavior dragStartBehavior = DragStartBehavior.start, ScrollViewKeyboardDismissBehavior keyboardDismissBehavior = ScrollViewKeyboardDismissBehavior.manual, WidgetPositionBuilder? feedback, WidgetPositionBuilder? childWhenDragging})
To achive the sticky header in horizontal gridview just call this horizontalStickyHeader constructor. By Default allHeaderChildNonDraggable is set to false making all header draggable. onWillAcceptHeader (Implement your logic on accepting and rejecting the drop of an header element), onReorderHeader (implement your logic for reodering and reindexing the elements) And if you want the header to be non-draggable element simple set allHeaderChildNonDraggable to true. itemBuilderHeader will be called only with indices greater than or equal to
const
DragAndDropView.stickyHeader({Key? key, bool reverse = false, ScrollController? controller, bool? primary, ScrollPhysics? physics, bool isCustomFeedback = false, bool isCustomChildWhenDragging = false, required WillAcceptCallback onWillAccept, WillAcceptCallback? onWillAcceptHeader, required IndexedWidgetBuilder itemBuilderHeader, bool allHeaderChildNonDraggable = false, SliverGridDelegate? headerGridDelegate, required ReorderCallback onReorder, ReorderCallback? onReorderHeader, int? headerItemCount, EdgeInsetsGeometry? headerPadding, EdgeInsetsGeometry? padding, required SliverGridDelegate gridDelegate, required IndexedWidgetBuilder itemBuilder, int? itemCount, bool addAutomaticKeepAlives = true, bool addRepaintBoundaries = true, bool addSemanticIndexes = true, double? cacheExtent, int? semanticChildCount, DragStartBehavior dragStartBehavior = DragStartBehavior.start, ScrollViewKeyboardDismissBehavior keyboardDismissBehavior = ScrollViewKeyboardDismissBehavior.manual, WidgetPositionBuilder? feedback, WidgetPositionBuilder? childWhenDragging})
To achive the sticky header in gridview just call this stickyHeader constructor. By Default allHeaderChildNonDraggable is set to false making all header draggable. onWillAcceptHeader (Implement your logic on accepting and rejecting the drop of an header element), onReorderHeader (implement your logic for reodering and reindexing the elements) And if you want the header to be non-draggable element simple set allHeaderChildNonDraggable to true. itemBuilderHeader will be called only with indices greater than or equal to
const

Properties

addAutomaticKeepAlive bool
finalinherited
addRepaintBoundaries bool
finalinherited
addSemanticIndexes bool
finalinherited
allHeaderChildNonDraggable bool
finalinherited
cacheExtent double?
finalinherited
childWhenDragging WidgetPositionBuilder?
finalinherited
controller ScrollController?
finalinherited
dragStartBehavior DragStartBehavior
finalinherited
feedback WidgetPositionBuilder?
finalinherited
gridDelegate SliverGridDelegate
finalinherited
hashCode int
The hash code for this object.
no setterinherited
finalinherited
headerGridDelegate SliverGridDelegate?
finalinherited
headerItemCount int?
finalinherited
headerPadding EdgeInsetsGeometry?
finalinherited
isCustomChildWhenDragging bool
finalinherited
isCustomFeedback bool
finalinherited
isStickyHeader bool
finalinherited
isVertical bool
finalinherited
itemBuilder IndexedWidgetBuilder
finalinherited
itemBuilderHeader IndexedWidgetBuilder?
finalinherited
itemCount int?
finalinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
keyboardDismissBehavior ScrollViewKeyboardDismissBehavior
finalinherited
makeRefreshable Widget

Available on Widget?, provided by the WidgetExtension extension

Make your any widget refreshable with RefreshIndicator on top
no setter
onReorder ReorderCallback
finalinherited
onReorderHeader ReorderCallback?
finalinherited
onWillAccept WillAcceptCallback
finalinherited
onWillAcceptHeader WillAcceptCallback?
finalinherited
padding EdgeInsetsGeometry?
finalinherited
physics ScrollPhysics?
finalinherited
primary bool?
finalinherited
reverse bool
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
semanticChildCount int?
finalinherited

Methods

center({double? heightFactor, double? widthFactor}) Widget

Available on Widget?, provided by the WidgetExtension extension

set parent widget in center
cornerRadiusWithClipRRect(double radius) ClipRRect

Available on Widget?, provided by the WidgetExtension extension

add corner radius
cornerRadiusWithClipRRectOnly({int bottomLeft = 0, int bottomRight = 0, int topLeft = 0, int topRight = 0}) ClipRRect

Available on Widget?, provided by the WidgetExtension extension

add custom corner radius each side
createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() MainGridViewState
Creates the mutable state for this widget at a given location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
expand({dynamic flex = 1}) Widget

Available on Widget?, provided by the WidgetExtension extension

add Expanded to parent widget
fit({BoxFit? fit, AlignmentGeometry? alignment}) Widget

Available on Widget?, provided by the WidgetExtension extension

add FittedBox to parent widget
flexible({dynamic flex = 1, FlexFit? fit}) Widget

Available on Widget?, provided by the WidgetExtension extension

add Flexible to parent widget
launch<T>(BuildContext context, {bool isNewTask = false, PageRouteAnimation? pageRouteAnimation, Duration? duration}) Future<T?>

Available on Widget?, provided by the WidgetExtension extension

Launch a new screen
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onTap(Function? function, {BorderRadius? borderRadius, Color? splashColor, Color? hoverColor, Color? highlightColor, Color? focusColor, WidgetStateProperty<Color?>? overlayColor}) Widget

Available on Widget?, provided by the WidgetExtension extension

add tap to parent widget
opacity({required double opacity, int durationInSecond = 1, Duration? duration}) Widget

Available on Widget?, provided by the WidgetExtension extension

add opacity to parent widget
paddingAll(double padding) Padding

Available on Widget?, provided by the WidgetExtension extension

return padding all
paddingBottom(double bottom) Padding

Available on Widget?, provided by the WidgetExtension extension

return padding bottom
paddingLeft(double left) Padding

Available on Widget?, provided by the WidgetExtension extension

return padding left
paddingOnly({double top = 0.0, double left = 0.0, double bottom = 0.0, double right = 0.0}) Padding

Available on Widget?, provided by the WidgetExtension extension

return custom padding from each side
paddingRight(double right) Padding

Available on Widget?, provided by the WidgetExtension extension

return padding right
paddingSymmetric({double vertical = 0.0, double horizontal = 0.0}) Padding

Available on Widget?, provided by the WidgetExtension extension

return padding symmetric
paddingTop(double top) Padding

Available on Widget?, provided by the WidgetExtension extension

return padding top
rotate({required double angle, bool transformHitTests = true, Offset? origin}) Widget

Available on Widget?, provided by the WidgetExtension extension

add rotation to parent widget
scale({required double scale, Offset? origin, AlignmentGeometry? alignment, bool transformHitTests = true}) Widget

Available on Widget?, provided by the WidgetExtension extension

add scaling to parent widget
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
tooltip({required String msg}) Widget

Available on Widget?, provided by the WidgetExtension extension

toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited
translate({required Offset offset, bool transformHitTests = true, Key? key}) Widget

Available on Widget?, provided by the WidgetExtension extension

add translate to parent widget
validate({Widget value = const SizedBox()}) Widget

Available on Widget?, provided by the WidgetExtension extension

Validate given widget is not null and returns given value if null.
visible(bool visible, {Widget? defaultWidget}) Widget

Available on Widget?, provided by the WidgetExtension extension

set visibility
withHeight(double height) SizedBox

Available on Widget?, provided by the WidgetExtension extension

With custom height
withRoundedCorners({Color backgroundColor = whiteColor, BorderRadius borderRadius = const BorderRadius.all(Radius.circular(8.0)), LinearGradient? gradient, BoxBorder? border, List<BoxShadow>? boxShadow, DecorationImage? decorationImage, BoxShape boxShape = BoxShape.rectangle}) Container

Available on Widget?, provided by the WidgetExtension extension

withScroll({ScrollPhysics? physics, EdgeInsetsGeometry? padding, Axis scrollDirection = Axis.vertical, ScrollController? controller, DragStartBehavior dragStartBehavior = DragStartBehavior.start, bool? primary, required bool reverse}) Widget

Available on Widget?, provided by the WidgetExtension extension

withShaderMask(List<Color> colors, {BlendMode blendMode = BlendMode.srcATop}) Widget

Available on Widget?, provided by the WidgetExtension extension

Wrap with ShaderMask widget
withShaderMaskGradient(Gradient gradient, {BlendMode blendMode = BlendMode.srcATop}) Widget

Available on Widget?, provided by the WidgetExtension extension

Wrap with ShaderMask widget Gradient
withShadow({Color bgColor = whiteColor, Color shadowColor = Colors.black12, dynamic blurRadius = 10.0, dynamic spreadRadius = 0.0, Offset offset = const Offset(0.0, 0.0), LinearGradient? gradient, BoxBorder? border, DecorationImage? decorationImage, BoxShape boxShape = BoxShape.rectangle}) Container

Available on Widget?, provided by the WidgetExtension extension

withSize({double width = 0.0, double height = 0.0}) SizedBox

Available on Widget?, provided by the WidgetExtension extension

With custom height and width
withTooltip({required String msg}) Widget

Available on Widget?, provided by the WidgetExtension extension

Validate given widget is not null and returns given value if null.
withVisibility(bool visible, {Widget? replacement, bool maintainAnimation = false, bool maintainState = false, bool maintainSize = false, bool maintainSemantics = false, bool maintainInteractivity = false}) Visibility

Available on Widget?, provided by the WidgetExtension extension

set widget visibility
withWidth(double width) SizedBox

Available on Widget?, provided by the WidgetExtension extension

With custom width

Operators

operator ==(Object other) bool
The equality operator.
inherited