StringExtension extension
- on
Properties
- isApk → bool
-
Available on String?, provided by the StringExtension extension
Document regexno setter - isAudio → bool
-
Available on String?, provided by the StringExtension extension
Audio regexno setter - isDoc → bool
-
Available on String?, provided by the StringExtension extension
Document regexno setter - isEmptyOrNull → bool
-
Available on String?, provided by the StringExtension extension
Returns true if given String is null or isEmptyno setter - isExcel → bool
-
Available on String?, provided by the StringExtension extension
Excel regexno setter - isHtml → bool
-
Available on String?, provided by the StringExtension extension
HTML regexno setter - isImage → bool
-
Available on String?, provided by the StringExtension extension
Image regexno setter - isInt → bool
-
Available on String?, provided by the StringExtension extension
no setter - isPdf → bool
-
Available on String?, provided by the StringExtension extension
PDF regexno setter - isPPT → bool
-
Available on String?, provided by the StringExtension extension
PPT regexno setter - isTxt → bool
-
Available on String?, provided by the StringExtension extension
Txt regexno setter - isVideo → bool
-
Available on String?, provided by the StringExtension extension
Video regexno setter - renderHtml → String
-
Available on String?, provided by the StringExtension extension
Render a HTML Stringno setter - reverse → String
-
Available on String?, provided by the StringExtension extension
It reverses the Stringno setter
Methods
-
calculateReadTime(
{int wordsPerMinute = 200}) → double -
Available on String?, provided by the StringExtension extension
Return average read time duration of given String in seconds -
capitalizeEachWord(
) → String -
Available on String?, provided by the StringExtension extension
This function returns given string with each word capital -
capitalizeFirstLetter(
) → String -
Available on String?, provided by the StringExtension extension
Capitalize given String -
convertYouTubeUrlToId(
{bool trimWhitespaces = true}) → String -
Available on String?, provided by the StringExtension extension
Get YouTube Video ID -
copyToClipboard(
) → Future< void> -
Available on String?, provided by the StringExtension extension
-
countWords(
) → int -
Available on String?, provided by the StringExtension extension
Return number of words ina given String -
formatNumberWithComma(
{String seperator = ','}) → String -
Available on String?, provided by the StringExtension extension
for ex. add comma in price -
getBoolInt(
) → bool -
Available on String?, provided by the StringExtension extension
Returns true if given value is '1', else returns false -
getNumericOnly(
{bool aFirstWordOnly = false}) → String -
Available on String?, provided by the StringExtension extension
Returns only numbers from a string trim Whitespaces -
getYouTubeThumbnail(
{bool trimWhitespaces = true}) → String -
Available on String?, provided by the StringExtension extension
Returns YouTube thumbnail for given video id -
isAlpha(
) → bool -
Available on String?, provided by the StringExtension extension
Check weather String is alpha or not -
isDigit(
) → bool -
Available on String?, provided by the StringExtension extension
Return true if given String is Digit -
isJson(
) → bool -
Available on String?, provided by the StringExtension extension
-
prefixText(
{required String value}) → String -
Available on String?, provided by the StringExtension extension
eg. Text("Dr. ${VARIABLE_NAME}"); => Text("VARIABLE_NAME.prefixText("Dr.")"); -
removeAllWhiteSpace(
) → String -
Available on String?, provided by the StringExtension extension
Removes white space from given String -
repeat(
int n, {String separator = ''}) → String -
Available on String?, provided by the StringExtension extension
Returns the given string n times -
setSearchParam(
) → List< String> -
Available on String?, provided by the StringExtension extension
returns searchable array for Firebase Database -
splitAfter(
Pattern pattern) → String -
Available on String?, provided by the StringExtension extension
Splits from apatternand returns remaining String after that -
splitBefore(
Pattern pattern) → String -
Available on String?, provided by the StringExtension extension
Splits from apatternand returns String before that -
splitBetween(
Pattern startPattern, Pattern endPattern) → String -
Available on String?, provided by the StringExtension extension
It matches the String and returns betweenstartPatternandendPattern -
suffixText(
{required String value}) → String -
Available on String?, provided by the StringExtension extension
eg. Text("${VARIABLE_NAME} /-"); => Text("VARIABLE_NAME.suffixText("/-")"); -
toastString(
) → void -
Available on String?, provided by the StringExtension extension
toast a String -
toBool(
) → bool -
Available on String?, provided by the StringExtension extension
Returns true if the validate() method returns 'true', otherwise returns false. -
toColor(
{Color? defaultColor}) → Color -
Available on String?, provided by the StringExtension extension
Get Color from HEX String -
toDouble(
{double defaultValue = 0.0}) → double -
Available on String?, provided by the StringExtension extension
Return double value of given string -
toInt(
{int defaultValue = 0}) → int -
Available on String?, provided by the StringExtension extension
Return int value of given string -
toList(
) → List< String> -
Available on String?, provided by the StringExtension extension
It return list of single character from String -
toSlug(
{String delimiter = '_'}) → String -
Available on String?, provided by the StringExtension extension
Generate slug of a given String -
toYouTubeId(
{bool trimWhitespaces = true}) → String -
Available on String?, provided by the StringExtension extension
Get YouTube Video ID -
validate(
{String value = ''}) → String -
Available on String?, provided by the StringExtension extension
-
validateEmail(
) → bool -
Available on String?, provided by the StringExtension extension
Check email validation -
validateEmailEnhanced(
) → bool -
Available on String?, provided by the StringExtension extension
Check email validation -
validatePhone(
) → bool -
Available on String?, provided by the StringExtension extension
Check phone validation -
validateURL(
) → bool -
Available on String?, provided by the StringExtension extension
Check URL validation